@@ -45,7 +45,7 @@ except ImportError:
     from urlparse import urljoin
     from urllib2 import urlopen
 
-__version__ = "0.7.2"
+__version__ = "0.8.0"
 
 
 # this pattern may be too aggressive
@@ -153,7 +153,7 @@ class Pynliner(object):
     def _get_url(self, url):
         """Returns the response content from the given url
         """
-        return urlopen(url).read()
+        return urlopen(url).read().decode()
 
     def _substitute_entities(self):
         """
